aboutsummaryrefslogtreecommitdiff
path: root/tests/server
diff options
context:
space:
mode:
authorJakub Jelen <jjelen@redhat.com>2019-05-30 17:43:54 +0200
committerAndreas Schneider <asn@cryptomilk.org>2019-06-13 16:28:25 +0200
commit03ca994cc048ac5af7c2722e9f4e4b27d8a95784 (patch)
tree7f66d8c5d419b7ff4d6a6d49a80293cd52699704 /tests/server
parent53ae2502f44f8fb8a34b620a7c6cbb53d80ed150 (diff)
downloadlibssh-03ca994cc048ac5af7c2722e9f4e4b27d8a95784.tar.gz
libssh-03ca994cc048ac5af7c2722e9f4e4b27d8a95784.tar.xz
libssh-03ca994cc048ac5af7c2722e9f4e4b27d8a95784.zip
tests: Use the SHA2 extension by default to avoid issues in FIPS mode
Diffstat (limited to 'tests/server')
-rw-r--r--tests/server/torture_server.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/server/torture_server.c b/tests/server/torture_server.c
index 6ed64238..ab9af4cb 100644
--- a/tests/server/torture_server.c
+++ b/tests/server/torture_server.c
@@ -461,8 +461,8 @@ static void torture_server_hostkey_mismatch(void **state)
rc = ssh_options_set(session, SSH_OPTIONS_USER, SSHD_DEFAULT_USER);
assert_ssh_return_code(session, rc);
- /* Configure the client to offer only ssh-rsa hostkey algorithm */
- rc = ssh_options_set(session, SSH_OPTIONS_HOSTKEYS, "ssh-rsa");
+ /* Configure the client to offer only rsa-sha2-256 hostkey algorithm */
+ rc = ssh_options_set(session, SSH_OPTIONS_HOSTKEYS, "rsa-sha2-256");
assert_ssh_return_code(session, rc);
rc = ssh_connect(session);